aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/device/xps
diff options
context:
space:
mode:
authorGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-29 11:54:56 +0000
committerGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-29 11:54:56 +0000
commit1f2f338e23789f3eef168dcbd8171a28820ba6c1 (patch)
treecfa6c68aca1dbad85f6ae0d3e1e616d9dac1369b /include/device/xps
parent3e8466a1520343e2e7d280d9d1f39b2bd048fbb9 (diff)
Split SkDevice into SkBaseDevice and SkBitmapDevice
Diffstat (limited to 'include/device/xps')
-rw-r--r--include/device/xps/SkXPSDevice.h19
1 files changed, 9 insertions, 10 deletions
diff --git a/include/device/xps/SkXPSDevice.h b/include/device/xps/SkXPSDevice.h
index dab8d1f6a3..c33e4503a1 100644
--- a/include/device/xps/SkXPSDevice.h
+++ b/include/device/xps/SkXPSDevice.h
@@ -13,10 +13,10 @@
#include <XpsObjectModel.h>
#include "SkAutoCoInitialize.h"
+#include "SkBitmapDevice.h"
#include "SkBitSet.h"
#include "SkCanvas.h"
#include "SkColor.h"
-#include "SkDevice.h"
#include "SkPaint.h"
#include "SkPath.h"
#include "SkPoint.h"
@@ -30,7 +30,7 @@
The drawing context for the XPS backend.
*/
-class SkXPSDevice : public SkDevice {
+class SkXPSDevice : public SkBitmapDevice {
public:
SK_API SkXPSDevice();
SK_API virtual ~SkXPSDevice();
@@ -134,7 +134,7 @@ protected:
virtual void drawDevice(
const SkDraw&,
- SkDevice* device,
+ SkBaseDevice* device,
int x, int y,
const SkPaint& paint) SK_OVERRIDE;
@@ -307,18 +307,17 @@ private:
const SkVector& ppuScale,
IXpsOMPath* shadedPath);
- // override from SkDevice
- virtual SkDevice* onCreateCompatibleDevice(
- SkBitmap::Config config,
- int width, int height,
- bool isOpaque,
- Usage usage) SK_OVERRIDE;
+ // override from SkBaseDevice
+ virtual SkBaseDevice* onCreateCompatibleDevice(SkBitmap::Config config,
+ int width, int height,
+ bool isOpaque,
+ Usage usage) SK_OVERRIDE;
// Disable the default copy and assign implementation.
SkXPSDevice(const SkXPSDevice&);
void operator=(const SkXPSDevice&);
- typedef SkDevice INHERITED;
+ typedef SkBitmapDevice INHERITED;
};
#endif